@@ -1,7 +1,9 @@
 package ZMQ::FFI::ContextRole;
-$ZMQ::FFI::ContextRole::VERSION = '1.07';
+$ZMQ::FFI::ContextRole::VERSION = '1.08';
 use Moo::Role;
 
+use ZMQ::FFI::Util qw(current_tid);
+
 # real underlying zmq ctx pointer
 has _ctx => (
     is      => 'rw',
@@ -14,6 +16,12 @@ has _pid => (
     default => sub { $$ },
 );
 
+# used to make sure we handle thread situations correctly
+has _tid => (
+    is      => 'ro',
+    default => sub { current_tid() },
+);
+
 has soname => (
     is       => 'ro',
     required => 1,
@@ -52,7 +60,7 @@ ZMQ::FFI::ContextRole
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 AUTHOR
 
