@@ -1,9 +1,10 @@
 package ZMQ::FFI::SocketRole;
-$ZMQ::FFI::SocketRole::VERSION = '1.07';
+$ZMQ::FFI::SocketRole::VERSION = '1.08';
 use FFI::Platypus;
 use FFI::Platypus::Memory qw(malloc);
 
 use ZMQ::FFI::Constants qw(zmq_msg_t_size);
+use ZMQ::FFI::Util qw(current_tid);
 
 use Moo::Role;
 
@@ -44,6 +45,12 @@ has _pid => (
     default => sub { $$ },
 );
 
+# used to make sure we handle thread situations correctly
+has _tid => (
+    is      => 'ro',
+    default => sub { current_tid() },
+);
+
 has sockopt_sizes => (
     is      => 'ro',
     lazy    => 1,
@@ -111,7 +118,7 @@ ZMQ::FFI::SocketRole
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 AUTHOR
 
