@@ -1,5 +1,5 @@
 package ZMQ::FFI::Util;
-$ZMQ::FFI::Util::VERSION = '1.07';
+$ZMQ::FFI::Util::VERSION = '1.08';
 # ABSTRACT: zmq convenience functions
 
 use strict;
@@ -13,6 +13,7 @@ use Sub::Exporter -setup => {
         zmq_soname
         zmq_version
         valid_soname
+        current_tid
     )],
 };
 
@@ -97,6 +98,17 @@ sub valid_soname {
     return defined $zmq_version;
 }
 
+sub current_tid {
+    if (eval 'use threads; 1') {
+        require threads;
+        threads->import();
+        return threads->tid;
+    }
+    else {
+        return -1;
+    }
+}
+
 1;
 
 __END__
@@ -111,7 +123,7 @@ ZMQ::FFI::Util - zmq convenience functions
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 SYNOPSIS
 
