@@ -1,7 +1,7 @@
 package ZMQ::FFI::ZMQ3::Context;
-$ZMQ::FFI::ZMQ3::Context::VERSION = '1.07';
+$ZMQ::FFI::ZMQ3::Context::VERSION = '1.08';
 use FFI::Platypus;
-use ZMQ::FFI::Util qw(zmq_soname);
+use ZMQ::FFI::Util qw(zmq_soname current_tid);
 use ZMQ::FFI::Constants qw(ZMQ_IO_THREADS ZMQ_MAX_SOCKETS);
 use ZMQ::FFI::ZMQ3::Socket;
 use Try::Tiny;
@@ -142,7 +142,10 @@ sub device {
 sub destroy {
     my ($self) = @_;
 
-    # don't try to cleanup context cloned from another process (fork)
+    # don't try to cleanup context cloned from another thread
+    return unless $self->_tid == current_tid();
+
+    # don't try to cleanup context copied from another process (fork)
     return unless $self->_pid == $$;
 
     $self->check_error(
@@ -151,7 +154,7 @@ sub destroy {
     );
 
     $self->_ctx(-1);
-};
+}
 
 sub DEMOLISH {
     my ($self) = @_;
@@ -175,7 +178,7 @@ ZMQ::FFI::ZMQ3::Context
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 AUTHOR
 
